@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.39';
+$VERSION = '1.40';
 
 sub ProcessJpeg2000Box($$$);
 sub ProcessJUMD($$$);
@@ -727,7 +727,6 @@ my %j2cMarker = (
         {
             Name => 'ColorSpecData',
             Format => 'undef[$size-3]',
-            Writable => 'undef',
             Protected => 1,
             Binary => 1,
         },
@@ -1443,7 +1442,7 @@ sub ProcessBrotli($$$)
             }
         } elsif ($type eq 'jumb') {
             return undef if $isWriting; # (can't yet write JUMBF)
-            Image::ExifTool::ProcessJUMB($et, \%dirInfo, $tagTablePtr); # (untested)
+            Image::ExifTool::Jpeg2000::ProcessJUMB($et, \%dirInfo, $tagTablePtr); # (untested)
         }
         if ($isWriting) {
             return undef unless defined $dat;
@@ -1544,7 +1543,7 @@ sub ProcessJP2($$)
 
     # check to be sure this is a valid JPG2000 file
     return 0 unless $raf->Read($hdr,12) == 12;
-    unless ($hdr eq "\0\0\0\x0cjP  \x0d\x0a\x87\x0a" or     # (ref 1)
+    unless ($hdr eq "\0\0\0\x0cjP  \x0d\x0a\x87\x0a" or       # (ref 1)
             $hdr eq "\0\0\0\x0cjP\x1a\x1a\x0d\x0a\x87\x0a" or # (ref 2)
             $$et{IsJXL})
     {
